application:setBackgroundColor(0x323232)

require "ImGui"

local imgui = ImGui.new()
stage:addChild(imgui)

--imgui:setLightStyle()

local tex = Texture.new("image.png", true)

local demoData = {
	mainWindowOpen = true,
	mainWindowDrawn = true,
	
	combo1 = {false,true,false},
	combo2 = "Item1\0item2\0Item3\0Item4\0Item5\0Item6\0Item7\0Item8\0Item9\0",
	combo2Item = 5,
	combo3 = {"Item1","item2","Item3","Item4","Item5","Item6","Item7","Item8","Item9","Item10"},
	combo3Item = 1,
	list1 = {"Item1","item2","Item3","Item4","Item5","Item6","Item7","Item8"},
	list1Item = 1,
	
	plotAnimate = true,
	plotOffset = 0,
	plotingTable1 = {  },
	plotingTable2 = {  },
}

for i = 1, 81 do 
	demoData.plotingTable1[i] = math.cos((math.pi/8)*(i-1)) * 100
	if (i <= 25) then 
		demoData.plotingTable2[i] = math.random() * (math.random() < 0.5 and -1 or 1)
	end
end
local timer = 0

local function imguiUnderlineText(text, color, alpha, thicknes)
	imgui:text(text)
	if (imgui:isItemHovered()) then 
		local minx, miny = imgui:getItemRectMin()
		local maxx, maxy = imgui:getItemRectMax()
		
		-- custom drawing function
		imgui:drawListAddLine(minx, maxy, maxx, maxy, color or 0xffffff, alpha or 1, thicknes or 1)
		
		if (imgui:isMouseClicked(KeyCode.MOUSE_LEFT)) then 
			-- clicked
		end
	end
end

local function helpMarker(desc)
    imgui:textDisabled("(?)")
    if (imgui:isItemHovered()) then 
        imgui:beginTooltip()
        imgui:pushTextWrapPos(imgui:getFontSize() * 35)
        imgui:textUnformatted(desc)
        imgui:popTextWrapPos()
        imgui:endTooltip()
    end
end

function enterFrame(e)
	timer += e.deltaTime
	
	imgui:newFrame(e)
	
	imgui:showDemoWindow()

	if (demoData.mainWindowOpen) then 
		demoData.mainWindowOpen, demoData.mainWindowDrawn = imgui:beginWindow("Dear ImGui v" .. ImGui._VERSION, demoData.mainWindowOpen)
		if (demoData.mainWindowDrawn) then 
			
			imguiUnderlineText("Hello world (hover me)", 0x00ff00, 1, 1) 
			imgui:sameLine()
			helpMarker("Tooltip :)")
			-- Custom drawing
			imgui:drawListAddPolyline({
				100, 100,
				200, 100,
				200, 200, 
				100, 200
			}, 0x00ff00, 1, true, 10)
			
			imgui:text("This is a LUA binding of ImGui library")
			if (imgui:treeNode("idCombos", "Combos")) then
				
				for i,v in ipairs(demoData.combo1) do 
					if (imgui:checkbox("CheckBox"..i, v)) then 
						demoData.combo1[i] = not v
					end
				end
				imgui:separator()
				
				imgui:text(("Selected: %02i"):format(demoData.combo2Item))
				imgui:sameLine()
				imgui:pushSID("eraseCombo1", nil)
				if (imgui:button("X")) then 
					demoData.combo2Item = -1
				end
				imgui:popID()
				imgui:sameLine()
				demoData.combo2Item = imgui:comboString("Combo 2", demoData.combo2Item, demoData.combo2, 5)
				
				imgui:text(("Selected: %02i"):format(demoData.combo3Item))
				imgui:sameLine()
				imgui:pushSID("eraseCombo2", nil)
				if (imgui:button("X")) then 
					demoData.combo3Item = -1
				end
				imgui:popID()
				imgui:sameLine()
				demoData.combo3Item = imgui:combo("Combo 3", demoData.combo3Item, demoData.combo3, 5)
				
				if (imgui:listBoxHeader("List", 0, 38)) then
					imgui:selectable("Selected", true)
					imgui:selectable("Not Selected", false)
					imgui:listBoxFooter()
				end
				demoData.list1Item = imgui:listBox("List box", demoData.list1Item, demoData.list1)
				
				imgui:treePop()
			end
			
			
			if (imgui:treeNode("idImages", "Images")) then 
				imgui:text("Original image is 200x200, but this one is 128x128")
				imgui:image(tex, 128, 128)
				imgui:text("Images can be tinted and can have a border.")
				imgui:image(tex, 128, 128, 0xff0000)
				imgui:sameLine()
				imgui:image(tex, 64, 64, 0x00ff00, 1, 0x0000ff, 1)
				
				imgui:text("Custom UV coordinates")
				imgui:image(tex, 128, 128, 0x0000ff, 1, 0x00ff00, 1, 0.5, 0.5)
				imgui:sameLine()
				imgui:image(tex, 128, 128, 0x0000ff, 1, 0x00ff00, 1, nil, nil, 0.2, 0.2)
				
				
				imgui:treePop()
			end
			
			if (imgui:treeNode("idPlots", "Plots")) then 
				if (imgui:checkbox("Animate", demoData.plotAnimate)) then 
					demoData.plotAnimate = not demoData.plotAnimate
				end
				
				if (demoData.plotAnimate) then 
					demoData.plotOffset += e.deltaTime * 10 
				end
				
				imgui:plotLines("Lines", demoData.plotingTable1, demoData.plotOffset, "as", -100, 100, 0, 100)
				imgui:plotHistogram("Histogram", demoData.plotingTable2, 0, "as", -1, 1, 0, 100)
				
				imgui:treePop()
			end
			
		end
		imgui:endWindow()
	end
	imgui:endFrame()
	imgui:render()
end

stage:addEventListener("mouseDown", function(e) imgui:onMouseDown(e) end)
stage:addEventListener("mouseUp", function(e) imgui:onMouseUp(e) end)
stage:addEventListener("mouseHover", function(e) imgui:onMouseHover(e) end)
stage:addEventListener("mouseMove", function(e) imgui:onMouseMove(e) end)
stage:addEventListener("mouseWheel", function(e) imgui:onMouseWheel(e) end)
stage:addEventListener("keyDown", function(e) imgui:onKeyDown(e) end)
stage:addEventListener("keyUp", function(e) imgui:onKeyUp(e) end)
stage:addEventListener("keyChar", function(e) imgui:onKeyChar(e) end)
stage:addEventListener("enterFrame", enterFrame)
